<?xml version="1.0"?>
<xsl:stylesheet version="2.0"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:variable name="siteprefix" select="/root/wo-constant/siteprefix" />
<xsl:variable name="servletprefix" select="/root/wo-constant/servletprefix" />

<!--
  replaces a substring in the specified string by another substring.

  @param source the source string
  @param old    the substring to be replaced
  @param new    the replacement for the substring
  
  @return the replaced string.
-->
<xsl:template name="replace-substring">
  <xsl:param name="source"/>
  <xsl:param name="old"/>
  <xsl:param name="new"/>
  <xsl:choose>
    <xsl:when test="contains($source[1],$old)" >
    	<xsl:variable name="before" select="substring-before($source[1],$old)" />
    	<xsl:value-of select="$before"/>
    	<xsl:copy-of select="$new"/>
    	<xsl:call-template name="replace-substring">
    		<xsl:with-param name="source" select="substring($source[1],string-length($before)+string-length($old)+1)" />
    		<xsl:with-param name="old" select="$old"/>
    		<xsl:with-param name="new" select="$new"/>
    	</xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
    	<xsl:value-of select="$source"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
  replaces a substring in the specified tree by another substring.

  @param source the source tree
  @param old    the substring to be replaced
  @param new    the replacement for the substring
  
  @return the replaced string.
-->
<xsl:template name="replace-substring-in-tree">
<xsl:param name="source"/>
<xsl:param name="old"/>
<xsl:param name="new"/>
<xsl:for-each select="$source/node()">
	<xsl:choose>
	<xsl:when test="self::text()">
		<xsl:choose>
		<xsl:when test="contains(.,$old)" >
			<xsl:variable name="before" select="substring-before(.,$old)" />
			<xsl:value-of select="$before"/>
			<xsl:copy-of select="$new"/>
			<xsl:call-template name="replace-substring-in-tree">
				<xsl:with-param name="source">
					<xsl:value-of select="substring(.,string-length($before)+string-length($old)+1)" />
				</xsl:with-param>
				<xsl:with-param name="old" select="$old"/>
				<xsl:with-param name="new" select="$new"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="."/>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:when>
	<xsl:when test="self::comment()" />
	<xsl:when test="self::processing-instruction()" />
	<xsl:otherwise>
		<xsl:copy>
		<!-- <xsl:element name="{local-name()}">  -->
			<!-- <xsl:apply-templates mode="namespace-copy" select="@*"/> -->
			<xsl:for-each select="@*">
				<xsl:variable name="aval">
					<xsl:call-template name="replace-substring">
						<xsl:with-param name="source" select="." />
						<xsl:with-param name="old" select="$old"/>
						<xsl:with-param name="new" select="$new"/>
					</xsl:call-template>			
				</xsl:variable>
				<xsl:attribute name="{local-name()}" namespace="{namespace-uri()}">
					<xsl:value-of select="$aval"/>			
				</xsl:attribute>
			</xsl:for-each>
			<xsl:call-template name="replace-substring-in-tree">
				<xsl:with-param name="source" select="." />
				<xsl:with-param name="old" select="$old"/>
				<xsl:with-param name="new" select="$new"/>
			</xsl:call-template>			
		</xsl:copy>
	</xsl:otherwise>
	</xsl:choose>
</xsl:for-each>
</xsl:template>

<!--
  If url already contains '?' returns '&amp;' otherwise returns '?'
  
  @param url		url to check

  @return the separator
-->
<xsl:template name="url-separator ">
	<xsl:param name="url" />
	<xsl:choose>
		<xsl:when test="contains($url,'?')">&amp;</xsl:when>
		<xsl:otherwise>?</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!--
  Formats the sub element 'date' of the current element.
  Assumes date is in the format yyyy/MM/dd HH:mm:ss+XX:yy
  where XX:yy is the timezone offset in hours:minutes
  
  @param shortdate		if true don't return time part of date

  @return the formatted date
-->
<xsl:template name="format-date">
	<xsl:param name="date" select="date" />
	<xsl:param name="shortdate" select="true()" />
	<xsl:param name="html" select="true()" />
	<xsl:variable name="year" select="substring($date, 3, 2)" />
	<xsl:variable name="month" select="number(substring($date, 6, 2))" />
	<xsl:variable name="day" select="number(substring($date, 9, 2))" />
	<xsl:variable name="time">
		<xsl:variable name="time24" select="substring-after($date, 'T')" />
		<xsl:variable name="hour" select="number(substring($time24,1,2))" />
		<xsl:variable name="minute" select="substring($time24,3,3)" />
		<xsl:choose>
			<xsl:when test="$hour = 0">
				<xsl:value-of select="12" />
			</xsl:when>
			<xsl:when test="$hour > 12">
				<xsl:value-of select="$hour - 12" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$hour" />
			</xsl:otherwise>
		</xsl:choose>
		<xsl:value-of select="$minute" />
		<xsl:choose>
			<xsl:when test="$hour >= 12">
				<xsl:text> PM</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text> AM</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="month-name">
		<xsl:choose>
		<xsl:when test="$month=1">Jan</xsl:when>
		<xsl:when test="$month=2">Feb</xsl:when>
		<xsl:when test="$month=3">Mar</xsl:when>
		<xsl:when test="$month=4">Apr</xsl:when>
		<xsl:when test="$month=5">May</xsl:when>
		<xsl:when test="$month=6">Jun</xsl:when>
		<xsl:when test="$month=7">Jul</xsl:when>
		<xsl:when test="$month=8">Aug</xsl:when>
		<xsl:when test="$month=9">Sep</xsl:when>
		<xsl:when test="$month=10">Oct</xsl:when>
		<xsl:when test="$month=11">Nov</xsl:when>
		<xsl:when test="$month=12">Dec</xsl:when>
		<xsl:otherwise>?</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	
	<xsl:value-of select="$day" />
	<xsl:choose>
		<xsl:when test="$html">
			<xsl:text>&#xA0;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text> </xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:value-of select="$month-name" />
	<xsl:choose>
		<xsl:when test="$html">
			<xsl:text>&#xA0;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text> </xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:value-of select="$year" />
	<xsl:if test="not($shortdate)">
		<xsl:value-of select="concat(', ', $time)" />
	</xsl:if>
</xsl:template>

<!--
  Gets a filname from the end of a full path.
  
  @param path		the path for the file

  @return the filename
-->
<xsl:template name="filename">
	<xsl:param name="path" select="undefined" />
	<xsl:choose>
	<xsl:when test="string($path) = ''" />
	<xsl:when test="contains($path,'/')">
		<xsl:call-template name="filename">
			<xsl:with-param name="path" select="substring-after($path,'/')" />
		</xsl:call-template>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="decoder:decode($path,'UTF-8')"
					xmlns:decoder="java:java.net.URLDecoder"/>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!--
  Gets the display name for topic URI

  @return the name
-->
<xsl:template name="get-topic-name">
	<xsl:param name="uri"></xsl:param>
	<xsl:choose>
		<xsl:when test="$uri/usertitle">
			<xsl:value-of select="$uri/usertitle" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$uri/title" />			
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!--
  Gets the display name for a URI

  @param uri				the URI node

  @return the name
-->
<xsl:template name="get-uri-name">
	<xsl:param name="uri" />
	<xsl:choose>
		<xsl:when test="$uri/displayname">
			<xsl:value-of select="$uri/displayname" />
		</xsl:when>
		<xsl:when test="$uri/usertitle">
			<xsl:value-of select="$uri/usertitle" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="filename">
				<xsl:with-param name="path" select="$uri/path" />
			</xsl:call-template>			
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!--
  Gets the default PageSeeder hostname URL

  @return the URL
-->
<xsl:template name="get-website-url">
	<xsl:variable name="websiteaddress" select="/root/wo-constant/websiteaddress" />
	<xsl:variable name="websiteport">
		<xsl:choose>
		<xsl:when test="/root/wo-constant/websiteport='80'"></xsl:when>
		<xsl:when test="/root/wo-constant/websiteport">:<xsl:value-of select="/root/wo-constant/websiteport" /></xsl:when>
		<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="websitescheme">
		<xsl:choose>
		<xsl:when test="/root/wo-constant/websitescheme">
			<xsl:value-of select="/root/wo-constant/websitescheme" />
		</xsl:when>
		<xsl:otherwise>http</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:value-of select="concat($websitescheme,'://',$websiteaddress,$websiteport)" />	
</xsl:template>

<!--
  @param xlink	the xlink element
  @return the display icon for the xlink.
-->
<xsl:template name="get-xlink-icon">
	<xsl:param name="xlink"/>
	<xsl:choose>
		<xsl:when test="contains($xlink/contentrole,'rchive')">archived_comment.gif</xsl:when>
		<xsl:when test="contains($xlink/status,'Open')">tick-open.gif</xsl:when>
		<xsl:when test="contains($xlink/status,'Resolved')">tick-resolved.gif</xsl:when>
		<xsl:when test="contains($xlink/status,'Closed')">tick-closed.gif</xsl:when>
		<xsl:when test="contains($xlink/contentrole,'pdf-')"><xsl:value-of select="contentrole" />.gif</xsl:when>
		<xsl:when test="$xlink/contentrole='File Attachment'">attachment.gif</xsl:when>
		<xsl:when test="$xlink/contentrole='File Upload'">attachment.gif</xsl:when>
		<xsl:when test="$xlink/contentrole='Description'">link.gif</xsl:when>
		<xsl:when test="starts-with($xlink/contentrole,'Documentation')">pencil.gif</xsl:when>
		<xsl:when test="$xlink/status">task.gif</xsl:when>
		<xsl:otherwise>comment.gif</xsl:otherwise>
	</xsl:choose>	
</xsl:template>

<!--
  @param xlink	the xlink element
  @return the title for the xlink.
-->
<xsl:template name="get-xlink-title">
	<xsl:param name="xlink"/>
	<xsl:if test="contains($xlink/properties,'version=')">
		<xsl:text>[</xsl:text>
		<xsl:value-of select="substring-before(substring-after($xlink/properties,'version='),'|')" />
		<xsl:text>] </xsl:text>
	</xsl:if>
	<xsl:if test="contains($xlink/properties,'docId=')">
		<xsl:text></xsl:text>
		<xsl:value-of select="substring-before(substring-after($xlink/properties,'docId='),'|')" />
		<xsl:text> - </xsl:text>
	</xsl:if>
	<xsl:value-of select="$xlink/contenttitle" />
</xsl:template>

<!--
  @param xlink	the xlink element
  @return the HTML (image) for representing the XLink's role
-->
<xsl:template name="xlink-role">
	<xsl:param name="xlink" select="." />
	<xsl:variable name="icon">
		<xsl:call-template name="get-xlink-icon">
			<xsl:with-param name="xlink" select="$xlink"/>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="title">
		<xsl:choose>
			<xsl:when test="$xlink/contentrole='Description'">Link</xsl:when>
			<xsl:otherwise><xsl:value-of select="$xlink/contentrole" /></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<img src="{$siteprefix}/weborganic/tree/images/{$icon}" title="{$title}" />
	<xsl:text> </xsl:text>
</xsl:template>

<!--
  @param groups		groups this xlink can be added to
  @return the HTML for the list of groups
-->
<xsl:template name="xlink-groups">
	<xsl:param name="groups"/>
	<xsl:variable name="member-list"
		select="concat($servletprefix, '/com.pageseeder.review.MemberList?grpId=')" />
	<b>This content will be available to these groups: </b>
	<xsl:for-each select="$groups/group">
		<xsl:if test="name!='admin'">
			| <a href="{concat($member-list,id,'&amp;redirect=true')}">
				<xsl:value-of select="name" />
			  </a>
			<xsl:if test="contains(flags,'p')">
				<xsl:text>&#xA0;(public)</xsl:text>
			</xsl:if>
		</xsl:if>
		<input type="hidden" name="groups" value="{name}" />
	</xsl:for-each>
</xsl:template>

<!--
  @param groups				groups this xlink can be added to
  @param current-groups		groups xlink currently belongs to (defaults to $groups)
  @return the HTML for choosing of groups
-->
<xsl:template name="xlink-groups-choice">
	<xsl:param name="groups"/>
	<xsl:param name="current-groups" select="$groups" />
	<xsl:variable name="member-list"
		select="concat($servletprefix, '/com.pageseeder.review.MemberList?grpId=')" />
	<b>This comment will be available to these groups:</b>
	<xsl:for-each select="$groups/group">
	  <input type="checkbox" name="groups" value="{name}">
		  <xsl:if test="$current-groups/group[name=current()/name]">
			<xsl:attribute name="checked">true</xsl:attribute>
		  </xsl:if>
	  </input>
	  <a href="{concat($member-list,id,'&amp;redirect=true')}">
	    <xsl:value-of select="name" />
	  </a>
	  <xsl:if test="contains(flags,'p')">
		<xsl:text>&#xA0;(public)</xsl:text>
	  </xsl:if>
	</xsl:for-each>
</xsl:template>

<!--
  @param assign-members		members this xlink can be assigned to
  @param assigned-to		member xlink currently assigned to
  @return the HTML for choosing of assigned to member
-->
<xsl:template name="xlink-assignto-choice">
	<xsl:param name="assign-members" />
	<xsl:param name="assigned-to" select="/.."/>
  <xsl:param name="select-class" select="''" />

  	<select name="assignTo" size="1">
    <xsl:if test="$select-class != ''"><xsl:attribute name="class"><xsl:value-of select="$select-class" /></xsl:attribute></xsl:if>
		<option value="">Nobody</option>
		<xsl:if test="$assigned-to and
					not($assign-members/member[id=$assigned-to/id])">
			<option value="{$assigned-to/id}" selected="true">
				<xsl:value-of select="$assigned-to/firstname"/>
				<xsl:text> </xsl:text>
				<xsl:value-of select="$assigned-to/surname"/>
			</option>
		</xsl:if>				
  		<xsl:for-each select="$assign-members/member">
        <xsl:sort select="surname" />
        <xsl:sort select="firstname" />
			<option value="{id}">
				<xsl:if test="$assigned-to/id=id">
					<xsl:attribute name="selected">true</xsl:attribute>
				</xsl:if>			
				<xsl:value-of select="firstname"/>
				<xsl:text> </xsl:text>
				<xsl:value-of select="surname"/>
			</option>
		</xsl:for-each>
	</select>
</xsl:template>

<!--
  @param value			the option value
  @param assigned-to	the selected option value
  @return the HTML for a drop down select option
-->
<xsl:template name="add-option">
	<xsl:param name="value" />
	<xsl:param name="value-selected" />

	<option value="{$value}">
		<xsl:if test="$value=$value-selected">
			<xsl:attribute name="selected">true</xsl:attribute>
		</xsl:if>			
		<xsl:value-of select="$value"/>
	</option>
</xsl:template>

</xsl:stylesheet>