<xsl:stylesheet version="2.0"
      xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
      xmlns:xs="http://www.w3.org/2001/XMLSchema"
      xmlns:ps="http://www.pageseeder.com/editing/2.0" 
      xmlns:svrl="http://purl.oclc.org/dsdl/svrl" 
      xmlns:sch="http://www.ascc.net/xml/schematron"
      xmlns:iso="http://purl.oclc.org/dsdl/schematron" 
      xmlns="http://www.w3.org/1999/xhtml" 
      exclude-result-prefixes="xsl xs ps svrl sch iso">

  <xsl:param name="css" />
  
  <xsl:output encoding="UTF-8" method="xhtml" indent="yes" />

  <xsl:template match="/">
    <html>
      <xsl:comment>no seeding</xsl:comment>
      <head>
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
        <title>Validation Report</title>
        <link rel="stylesheet" href="{$css}" type="text/css" />
      </head>
      <body>
        <h1>Validation Report</h1>
        <xsl:for-each select="fileset/file">
          <xsl:apply-templates select="." />
        </xsl:for-each>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="file">

    <xsl:choose>
      <xsl:when test="svrl:schematron-output/svrl:failed-assert[contains(.,'FATAL')]">
        <h3 class="error">Results: The file is <span style="color:red">INVALID</span>. Please see the notes below:</h3>
      </xsl:when>
      <xsl:when test="count(svrl:schematron-output/svrl:failed-assert) != 0">
        <h3 class="warning">Results: The file is valid, but with the following warning(s):</h3>
      </xsl:when>
      <xsl:otherwise>
        <h3 class="ok">Results: The file is valid</h3>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:apply-templates />

  </xsl:template>

  <!-- 
    Display the schematron output grouping by error message
  -->
  <xsl:template match="svrl:schematron-output">
    <xsl:for-each select="svrl:successful-report|svrl:failed-assert">
      <div class="{local-name(.)}">
        <h4><xsl:value-of select="svrl:text"/></h4>
      </div>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="text()" />

</xsl:stylesheet>

