<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
							  xmlns:psf="http://www.pageseeder.com/function"
	                          xmlns:ps="http://www.pageseeder.com/editing/2.0"
	                          exclude-result-prefixes="psf">
  <!--
    Templates used to produce Table of Contents (TOC) XML.

    @author  Willy Ekasalim
    @version 26 November 2007
  
    Copyright (C) 2007 Weborganic Systems Pty. Ltd.
  -->
	
  <!-- import the functions -->
  <xsl:import href="../../Common/TOCUtilities.xsl" />
  <xsl:output method="xml" version="1.0" indent="no"/>

  <!-- if false don't generate TOC -->
  <xsl:param name="toc" select="'true'"/>
  
  <xsl:param name="styleowner" select="''"/>
  <xsl:param name="customfolder" select="''"/>
  <!--
	Structure for TOC XML (before toc id-ing and numbering)
	< >
	  <level1 comment="true" type="heading">Work Package</level1>
      <level1 comment="true" type="heading" numbered="true">Heading 1</level1>
      <level2 comment="true" type="heading" numbered="true">Heading 2</level2>
      <level2 comment="true" type="heading">Heading 2</level2>
      <xref ... href="/ps/test4/contents.xml">Xref link</xref>
      <level3 comment="true" type="heading" numbered="true">Heading 3</level3>
	</>
	
	Structure for TOC XML (after toc id-ing and numbering)
	< >
	  <level1 comment="true" type="heading">Work Package</level1>
      <level1 comment="true" type="heading" numbered="true" label="1.">Heading 1</level1>
      <level2 comment="true" type="heading" numbered="true" label="1.1">Heading 2</level2>
      <level2 comment="true" type="heading">Heading 2</level2>
      <xref ... href="/ps/test4/contents.xml">Xref link</xref>
      <level3 comment="true" type="heading" numbered="true" label="1.1.1">Heading 3</level3>
	</>  
  -->

  <xsl:template match="processing-instruction()">
    <xsl:copy-of select="." />
  </xsl:template>
  
  <xsl:template match="/root">
  	<!--id and numebring phase -->
  	<xsl:variable name="toc-pre">
  	  <toc>
  	    <xsl:copy-of select="properties"/>
  	    <xsl:copy-of select="psf:get-titles(.)"/>
  	  </toc>
  	</xsl:variable>
    <xsl:variable name="numbering-config">
      <xsl:choose>
        <xsl:when test="doc-available(concat('../../../', $styleowner, '/format-standard/Document/defaultNumberingConfig.xml'))">
          <xsl:sequence select="document(concat('../../../', $styleowner, '/format-standard/Document/defaultNumberingConfig.xml'))" />
        </xsl:when>
        <xsl:when test="doc-available(concat('../../../', $customfolder, '/format-standard/Document/defaultNumberingConfig.xml'))">
          <xsl:sequence select="document(concat('../../../', $customfolder, '/format-standard/Document/defaultNumberingConfig.xml'))" />
        </xsl:when>
        <xsl:otherwise><xsl:sequence select="document('defaultNumberingConfig.xml')" /></xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="toc-with-idnumbering">
  	  <ps:toc>
  	    <xsl:copy-of select="psf:toc-id-numbering($toc-pre/toc/*, $numbering-config)"/>
  	  </ps:toc>
  	</xsl:variable>
  	<!-- end of id-numbering phase-->
  	<root>
      <xsl:copy-of select="@*" />
      <xsl:if test="$toc!='false'">
    	  <ps:documentinfo>
    		  <xsl:copy-of select="ps:documentInfo/*  | ps:documentinfo/*"/>
    		  <!-- copying the toc element-->
          <ps:toc><xsl:copy-of select="$toc-with-idnumbering/ps:toc/*[@type != 'para']"/></ps:toc>
    	  </ps:documentinfo>
      </xsl:if>
  	  <!-- go through all the heading and apply the label-->
  	  <xsl:apply-templates mode="section-copy" select="*[not(self::ps:documentInfo or self::ps:documentinfo or self::ps:fragmentnfo)]
                                                        [not(ancestor::ps:documentation[ps:status='Compare'])]">
  	    <xsl:with-param name="toc-id" select="$toc-with-idnumbering" tunnel="yes"/>
  	  </xsl:apply-templates>
  	</root>
  </xsl:template>
	
  <!-- 
	Function to produce TOC XML Strcuture
	@param root, the data of the document  
  -->
  <xsl:function name="psf:get-titles">
    <xsl:param name="root"/>
    <xsl:for-each select="$root//*[not(ancestor::ps:documentation[ps:status='Compare'])]
                                  [(starts-with(name(), 'heading') and name() != 'heading') or (name() = 'para' and @numbered = 'true') or
                                   (name() = 'title' and (parent::root or parent::section) and (if (@level) then (@level != 'table') else true()))]">
      <xsl:choose>
  	    <xsl:when test="starts-with(name(), 'heading')">
  	      <xsl:element name="level{substring-after(name(),'heading')}">
    		    <xsl:if test="ancestor::ps:part/ps:discussion//xlink">
    		      <xsl:attribute name="comment">true</xsl:attribute>
    		    </xsl:if>
    		    <xsl:attribute name="type">heading</xsl:attribute>
    	        <xsl:copy-of select="@*"/>
    		    <xsl:apply-templates mode="contents-link"/>
    		  </xsl:element>
  	    </xsl:when>
  	    <xsl:when test="self::title">
          <xsl:element name="level{if (parent::root) then '0' else if (not(@level)) then '1' else @level}">
    		    <xsl:if test="ancestor::section//ps:discussion//xlink">
    		      <xsl:attribute name="comment">true</xsl:attribute>
    		    </xsl:if>
    		    <xsl:attribute name="type">title</xsl:attribute>
    	        <xsl:copy-of select="@*"/>
    		    <xsl:apply-templates mode="contents-link"/>
    		  </xsl:element>
  	    </xsl:when>
        <xsl:when test="self::para[@numbered][@indent]">
          <xsl:element name="level{@indent}">
            <xsl:if test="ancestor::ps:part/ps:discussion//xlink">
              <xsl:attribute name="comment">true</xsl:attribute>
            </xsl:if>
            <xsl:attribute name="type">para</xsl:attribute>
            <xsl:copy-of select="@*"/>
            <xsl:apply-templates mode="contents-link"/>
          </xsl:element>
        </xsl:when>
  	  </xsl:choose>
    </xsl:for-each>
  </xsl:function>

  <!--
    The following are templates to copy all root content, with special templates for heading
  -->
  <!-- template to copy all nodes content except xref -->
  <xsl:template match="*" mode="section-copy">
    <xsl:copy>
      <xsl:copy-of select="@*"/>
      <xsl:apply-templates mode="section-copy"/>
    </xsl:copy>
  </xsl:template>

  <!--
    Template to handle duplicate body and section ids
  -->
  <!-- template to copy all nodes content except xref -->
  <xsl:template match="section | body" mode="section-copy">
    <xsl:copy>
      <xsl:copy-of select="@*[name() != 'id']"/>
      <xsl:variable name="before" select="preceding::*[name() = current()/name()][@id = current()/@id] |
                                          ancestor::*[name() = current()/name()][@id = current()/@id]" />
      <xsl:attribute name="id" select="if ($before) then concat(@id, '-', count($before)) else @id" />
      <xsl:apply-templates mode="section-copy"/>
    </xsl:copy>
  </xsl:template>

  <!--
    Template to copy numbered heading element and also populate its label and id attribute
  -->
  <xsl:template match="*[ancestor::section and not(ancestor::ps:discussion) and not(ancestor::ps:xrefs)]
                        [(starts-with(name(),'heading') and name() != 'heading') or self::para[@numbered]]" mode="section-copy">
  	<xsl:param name="toc-id" tunnel="yes"/>
  	<xsl:element name="{name()}">
  	  <xsl:copy-of select="@*"/>
      <!-- generate id of this numbered heading, by calculating total number of preceding heading and preceding title element-->
  	  <xsl:variable name="id" select="count(preceding::*[not(ancestor::ps:documentation[ps:status='Compare'])]
                                                        [(starts-with(name(),'heading') and name() != 'heading') or self::para[@numbered='true']]) +
  		                                count(preceding::*[not(ancestor::ps:documentation[ps:status='Compare'])][starts-with(name(),'title')]
  		                                                  [parent::root or parent::section]
  		                                                  [if (@level) then (@level != 'table') else true()])"/>
  	  <!-- look into the generated id&numbering variable and take its label and href-->
  	  <xsl:variable name="matching-toc" select="$toc-id//*[starts-with(name(),'ps:level')][@idref=concat('toc-',$id)]"/>
  	  <xsl:if test="$matching-toc/@label"><xsl:attribute name="label" select="$matching-toc/@label"/></xsl:if>
  	  <xsl:attribute name="id" select="concat('toc-',$id)"/>
  	  <xsl:if test="@numbered"><xsl:attribute name="numbered" select="@numbered"/></xsl:if>
      <xsl:copy-of select="node()"/>
  	</xsl:element>
  </xsl:template>
	
  <!-- 
    Template to copy title element and also populate its id attribute
  -->
  <xsl:template match="*[parent::root or parent::section][starts-with(name(),'title')][if (@level) then (@level != 'table') else true()]" mode="section-copy">
  	<xsl:param name="toc-id" tunnel="yes"/>
  	<xsl:element name="{name()}">
  	  <xsl:copy-of select="@*"/>
      <!-- generate id of this numbered heading, by calculating total number of preceding heading and preceding title element-->
  	  <xsl:variable name="id" select="count(preceding::*[not(ancestor::ps:documentation[ps:status='Compare'])]
                                                        [(starts-with(name(),'heading') and name() != 'heading') or self::para[@numbered='true']]) +
  		                                count(preceding::*[not(ancestor::ps:documentation[ps:status='Compare'])][starts-with(name(),'title')]
  		                                                  [parent::root or parent::section]
  		                                                  [if (@level) then (@level != 'table') else true()])"/>
  	  <!-- look into the generated id&numbering variable and take its label and href, there's no numbered for title-->
  	  <xsl:variable name="matching-toc" select="$toc-id//*[starts-with(name(),'ps:level')][@idref=concat('toc-',$id)]"/>
  	  <xsl:attribute name="id" select="concat('toc-',$id)"/>
      <xsl:copy-of select="node()"/>
  	</xsl:element>
  </xsl:template>
  
  <xsl:template match="br" mode="contents-link">
    <xsl:text>&#160;</xsl:text>
  </xsl:template>
	
</xsl:stylesheet>