<?xml version="1.0"?>
<!--
  Templates used to display the files for a project.
  
  @author Jean-Baptiste Reure
  @author Christophe Lauret
  @version 18 August 2011
-->
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns:xs="http://www.w3.org/2001/XMLSchema"
                              xmlns:psf="http://www.pageseeder.com/function"
                              exclude-result-prefixes="xs psf">
  
  <!-- General Output properties (HTML5) -->
  <xsl:output method="html" encoding="utf-8" indent="no" undeclare-prefixes="no" media-type="text/html" />

  <xsl:variable name="context-path" select="/root/header/context-path"/>
  
  <!-- Main template -->
  <xsl:template match="/">
    <xsl:apply-templates select="root" />
  </xsl:template>
  
  <!-- Main template -->
  <xsl:template match="root">
    <!-- Display the HTML Doctype -->
    <xsl:text disable-output-escaping="yes"><![CDATA[<!doctype html>
    ]]></xsl:text> 
    <html>
      <head>
        <title>Publish Engine Manager</title> 
        <meta http-equiv="Content-Language"    content="en"/>
        <meta http-equiv="Content-Script-Type" content="text/javascript"/>
        <meta http-equiv="Content-Style-Type"  content="text/css"/>
        <link rel="stylesheet" type="text/css" href="{$context-path}/css/lib/foundation-5.5.3.min.css" media="screen"/>
        <link rel="stylesheet" type="text/css" href="{$context-path}/css/lib/normalize-3.0.2.css" media="screen"/>
        <link rel="stylesheet" type="text/css" href="{$context-path}/css/lib/jquery-ui-1.11.4.min.css" media="screen"/>
        <link rel="stylesheet" type="text/css" href="{$context-path}/css/global.css" media="screen"/>
        <link rel="stylesheet" type="text/css" href="{$context-path}/css/navigation.css" media="screen"/>
        <xsl:if test="unparsed-text-available(concat('../../../css/service/', header/service ,'.css'))">
          <link rel="stylesheet" type="text/css" href="{$context-path}/css/service/{header/service}.css" media="screen"/>
        </xsl:if>
        <xsl:call-template name="ie-conditional-comments"/>
        <script src="{$context-path}/js/lib/jquery/jquery-1.11.2.min.js"></script>
        <script src="{$context-path}/js/lib/jquery/jquery-ui-1.11.4.min.js"></script>
      </head>
      <body class="ps-layout-page">
        <div id="ps-container">
          <header id="ps-header" role="banner">
            <xsl:apply-templates select="." mode="header" />
          </header>
          <nav id="ps-navigation" role="navigation">
            <xsl:apply-templates select="." mode="navigation" />
          </nav>
          <div id="ps-body">
            <main id="ps-main" role="main">
              <div id="ps-content-{header/service}" class="content">
                <xsl:apply-templates select="content[@target = 'main']" />
              </div>
            </main>
          </div>
          <footer id="ps-footer" role="contentinfo">
            <xsl:apply-templates select="." mode="footer" />
          </footer>
        </div>
        <script src="{$context-path}/js/lib/foundation.min.js"/>
        <script src="{$context-path}/js/vendor/modernizr.js"></script>
        <script>$(document).foundation();</script>
        <script src="{$context-path}/js/global.js"></script>
        <!-- Auto load the script if it exists -->
        <xsl:if test="unparsed-text-available(concat('../../../js/service/', header/service ,'.js'))">
          <script src="{$context-path}/js/service/{header/service}.js"></script>
        </xsl:if>
      </body>
    </html>
  </xsl:template>
  
  <!-- Displays the header for the page -->
  <xsl:template match="root" mode="header">
    <div class="header-logo medium-4 columns">
      <a href="/ps/page/home">&#160;</a>
    </div>
    <h1 class="medium-8 columns medium-text-right hide-for-small-only">Publisher Engine</h1>
  </xsl:template>
  
  <!-- Displays the footer for the page -->
  <xsl:template match="root" mode="footer">
    <ul class="inline-list">
      <li><a href="http://www.pageseeder.com"  class="external" target="_blank">pageseeder.com</a></li>
      <li><a href="http://user.pageseeder.com" class="external" target="_blank">Help</a></li>
      <li><a href="http://dev.pageseeder.com"  class="external" target="_blank">Developers</a></li>
    </ul>
    <div class="ps-copyright">Copyright © 1999-2015 Weborganic Pty Ltd</div>
  </xsl:template>

  <xsl:template match="root" mode="navigation">
    <xsl:variable name="s" select="header/service"/>
    <div class="bottom row">
      <div class="columns medium-4 large-3">
        <div id="ps-nav-account-options">
          <div id="ps-nav-user">
            <xsl:apply-templates select="content[@name = 'user']" />
          </div>
        </div>
      </div>
      <div id="ps-nav-pages" class="medium-8 large-9">
        <xsl:if test="content[@name = 'user'][user]">
          <div id="pages-for-project">
            <ul class="pages">
              <li class="subtab{if ($s = 'projects' or $s = 'project') then ' current' else''}">
                <a href="{$context-path}/admin/projects.html">Projects</a>
              </li>
              <li class="subtab{if ($s = 'status') then ' current' else''}">
                <a href="{$context-path}/admin/status.html">Status</a>
              </li>
              <li class="subtab{if ($s = 'about') then ' current' else''}">
                <a href="{$context-path}/admin/about.html">About</a>
              </li>
              <li class="subtab{if ($s = 'settings') then ' current' else''}">
                <a href="{$context-path}/admin/settings.html">Properties</a>
              </li>
            </ul>
          </div>
        </xsl:if>
      </div>
      <!-- 
      <div id="ps-perspectives"></div>
      <div id="ps-nav-pages" class="medium-8 medium-offset-4 large-9 large-offset-3"></div>
       -->
    </div>
  </xsl:template>

  <xsl:template match="content[@name = 'user'][user]">
    <div class="user">
      <xsl:value-of select="concat(user/firstname, ' ', user/surname)" />
      <xsl:text>&#160;|&#160;</xsl:text>
      <a href="{$context-path}/logout.html">Logout</a>
    </div>
  </xsl:template>

  <!-- 
    Display the Scripts and Styles to be included in the HTML head
  -->
  <xsl:template name="ie-conditional-comments">
  <xsl:comment><![CDATA[[if IE 9]>
    <link rel="stylesheet" type="text/css" href="]]><xsl:value-of select="$context-path" /><![CDATA[/css/ie9.css"></link>
  <![endif]]]></xsl:comment>
  <xsl:comment><![CDATA[[if IE 8]>
    <link rel="stylesheet" type="text/css" href="]]><xsl:value-of select="$context-path" /><![CDATA[/css/ie8.css"></link>
    <script src="]]><xsl:value-of select="$context-path" /><![CDATA[/js/ie-html5.js" type="text/javascript"></script>
  <![endif]]]></xsl:comment>
  <xsl:comment><![CDATA[[if IE 7]>
    <link rel="stylesheet" type="text/css" href="]]><xsl:value-of select="$context-path" /><![CDATA[/css/ie7.css"></link>
    <script src="]]><xsl:value-of select="$context-path" /><![CDATA[/js/ie-html5.js" type="text/javascript"></script>
  <![endif]]]></xsl:comment>
  </xsl:template>
  
</xsl:stylesheet>
