<?xml version="1.0"?>
<!--
  Templates used to display the files for a project.
  
  @author Jean-Baptiste Reure
  @author Christophe Lauret
  @version 18 August 2011
-->
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns:xs="http://www.w3.org/2001/XMLSchema"
                              xmlns:psf="http://www.pageseeder.com/function"
                              exclude-result-prefixes="xs psf">
  
  <xsl:import href="common.xsl"/>
  
  <!-- HTML output -->
  <xsl:output method="html" encoding="utf-8" indent="no" undeclare-prefixes="no" media-type="text/html" />
  
  <xsl:template match="content[@name = 'login']">
    <div class="login">
      <xsl:call-template name="login-form">
        <xsl:with-param name="heading">
          <xsl:choose>
            <xsl:when test="//header/http-parameters/parameter[@name = 'message'] = 'Login failed'">Invalid login/password, please try again:</xsl:when>
            <xsl:otherwise>Please authenticate on the PageSeeder Server using the form below:</xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>
    </div>
  </xsl:template>

  <xsl:template match="content[@name = 'logout']">
    <div class="login">
      <xsl:call-template name="login-form">
        <xsl:with-param name="heading">You have successfully logged out.<br/>Use the form below to login again:</xsl:with-param>
      </xsl:call-template>
    </div>
  </xsl:template>

  <xsl:template match="content[@name = 'error']">
    <xsl:variable name="code" select="//header/uri-parameters/parameter[@name = 'code']" />
    <xsl:choose>
      <xsl:when test="$code = '401'">
        <div class="login">
          <xsl:call-template name="login-form" />
        </div>
      </xsl:when>
      <xsl:when test="$code = '403'">
        <div class="login">
          <xsl:call-template name="login-form">
            <xsl:with-param name="heading">Only PageSeeder Administrators can access the Publish Engine interface,<br/>
                                           please log in using an administrator account:</xsl:with-param>
          </xsl:call-template>
        </div>
      </xsl:when>
      <xsl:when test="$code = '404'">
        <h2>Lost?</h2>
        <div class="error">This path does not resolve to a valid location.</div>
      </xsl:when>
      <xsl:when test="$code = '500'">
        <h2>Server error</h2>
        <div class="error">It seems that something went wrong on the server!</div>
        <pre><xsl:copy-of select=".." /></pre>
      </xsl:when>
      <xsl:otherwise>
        <div class="error">There was an error of type <xsl:value-of select="$code" />!</div>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="login-form">
    <xsl:param name="heading">Please authenticate on the PageSeeder Server using the form below:</xsl:param>
    <div class="collapse row">
      <div class="small-12 columns"><xsl:copy-of select="$heading" /></div>
    </div>
    <div class="collapse row">
      <div class="small-6 medium-4 columns end">
        <form id="ps-login-form" action="{$context-path}/login" method="POST">
          <p><label>Pageseeder Host: <input id="pshost" name="pshost" value="{//properties/property[@name = 'ps-publisher.host']/@value}" maxlength="100" type="text" readonly="true" /></label></p>
          <p><label>Email/Username: <input id="username" name="username" value="" maxlength="100" type="text" /></label></p>
          <p><label>Password: <input id="password" name="password" maxlength="100" type="password" /></label></p>
          <p></p>
          <p><button type="submit" class="submit">Login</button></p>
        </form>
      </div>
    </div>
  </xsl:template>

</xsl:stylesheet>
