<?xml version="1.0"?>
<!--
  Templates used to display the status for a project.

  @author Jean-Baptiste Reure
  @author Christophe Lauret
  @version 17 March 2011
-->
<xsl:stylesheet version="2.0" xmlns="http://www.w3.org/1999/xhtml"
                              xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns:xs="http://www.w3.org/2001/XMLSchema"
                              xmlns:psf="http://www.pageseeder.com/function"
                              exclude-result-prefixes="xs psf">

  <xsl:variable name="context-path" select="/root/header/context-path"/> 

  <!-- Main template -->
  <xsl:template match="content[@name = 'status']">
    <h2>Status on <xsl:value-of select="format-dateTime(current-dateTime(), '[D] [MNn,*-3] [Y] at [H01]:[m01]')" /></h2>
    <a href="{$context-path}/admin/status.html" class="refresh"><span>Refresh</span></a>
    <xsl:apply-templates select="status/publish" mode="status" />
    <xsl:if test="empty(status/publish)">
      <div class="empty">No jobs currently running.</div>
    </xsl:if>
  </xsl:template>
  
  <!-- publish -->
  <xsl:template match="publish" mode="status">
    <div class="publish-job">
      <div class="actions">
        <a href="{$context-path}/admin/embed/cancel" processid="{@id}" class="cancel">cancel</a>
      </div>
      <h3>Publish Job for <xsl:choose>
        <xsl:when test="parameters/ps-uriId">URI <xsl:value-of select="parameters/ps-uriPath" /></xsl:when>
        <xsl:otherwise>Group <xsl:value-of select="parameters/ps-groupName" /></xsl:otherwise>
      </xsl:choose></h3>
      <div class="status">Current Status: <xsl:value-of select="status" /></div>
      <div class="parameters">
        <div class="title"><a href="#">Show Parameters</a></div>
        <table class="parameters-content">
          <thead><tr><th>Name</th><th>Value</th></tr></thead>
          <tbody>
            <xsl:for-each select="parameters/*">
              <xsl:sort select="name()" />
              <tr class="{if (position() mod 2 = 0) then 'even' else 'odd'}"><td><xsl:value-of select="name()" /></td><td><xsl:value-of select="."/></td></tr>
            </xsl:for-each>
          </tbody>
        </table>
      </div>
      <div class="messages">
        <div class="title"><a href="#">Show Messages</a></div>
        <div class="messages-content">
          <xsl:apply-templates select="message" mode="status" />
        </div>
      </div>
    </div>
  </xsl:template>
  
  <xsl:template match="message" mode="status">
    <xsl:if test="empty(preceding::message[@target = current()/@target])">
      <div class="target"><xsl:value-of select="@target" /></div>
    </xsl:if>
    <div class="message">
      <xsl:value-of select="." />
    </div>
  </xsl:template>
  
</xsl:stylesheet>
