/**
 * An implementation of the BreadcrumbBar using the jQuery JavaScript Library v1.3.2
 * http://jquery.com/
 *
 * @author Jean-Baptiste Reure
 * @version 19 May 2009
 */

/*global jQuery */

if (jQuery) {
 (function ($) {
  $.extend($.fn, {

    psBcb: function(o) {
      // Defaults
      if (!o) {o = {};}
      if (o.speed === undefined) {
        o.speed = 10;
      }

      $(this).each( function() {

        /**
         * @param url The URL to invoke.
         * @return The same URL with a timestamp to prevent caching.
         */
        function noCache(url) {
          return url + ((url.indexOf('?') >= 0)? '&' : '?')+ 't=' + (new Date()).getTime();
        }

        /**
         * Load the content using AJAX and handles failed login.
         * 
         * @param cont   The content HTML element
         * @param c      The component where the URL to load is taken from.
         */
        function loadContent(cont, c) {
          // We load the children of the DIV block
          var url = $(c).attr('href');
          if (url == '#') {
            $(c).parents('div.ps-bcb').find('.loading').addClass('hidden');
            return;
          }
          $(cont).load(noCache(url)+' div.ps-bcb-breadcrumb>*', '', function(responseText, textStatus, XMLHttpRequest) {
            var $content = $(this); 
            switch (XMLHttpRequest.status) {
              case 500:
                // hide loading div
                $(c).parents('div.ps-bcb').find('.loading').addClass('hidden');
                $content.html('<p>An error occurred.</p>');
                return;
              case 403:
                // hide loading div
                $(c).parents('div.ps-bcb').find('.loading').addClass('hidden');
                $content.html('<p>Access Denied</p>');
                return;
              case 401:
                // unauthorized, show login dialog window
                PAGESEEDER.Login.loginDialog(function() {
                  // succeeded, load content again
                  loadContent(cont, c);
                }, function() {
                  // hide loading div
                  $(c).parents('div.ps-bcb').find('.loading').addClass('hidden');
                  // user closed the login dialog, show message
                  $content.html('<p>Access Denied</p>');
                });
                return;
              default:
                // hide loading div
                $(c).parents('div.ps-bcb').find('.loading').addClass('hidden');
                // turn on links
                bindLinks($content);
                if (o.httpcallback) {
                  if (typeof(o.httpcallback) === 'function') {
                    var completepath = '';
                    $(c).parents('.ps-bcb').find('a.ps-bcb-item[href!=#]').each(function() {completepath += $(this).text() + '/';});
                    o.httpcallback(responseText, textStatus, XMLHttpRequest);
                  }
                }
            }
          });
        }

        /**
         * load the next item in the breadcrumb bar using ajax
         */
        function loadNextBreadCrumb(c, id, type) {
          // show loading div
          $(c).parents('div.ps-bcb').find('.loading').removeClass('hidden');
          // hide the menu
          var $breadcrumb = $(c).parent('div.ps-bcb-breadcrumb');
          $breadcrumb.find('div.ps-bcb-items:first').slideUp(o.speed);
          $breadcrumb.find('a.ps-bcb-delim').addClass('expand').removeClass('collapse');
          // remove all the following breadcrumbs and create the next one
          $breadcrumb.nextAll('div.ps-bcb-breadcrumb').remove();
          $breadcrumb.after('<div class="ps-bcb-breadcrumb"></div>');
          // now load the new contents in the newly created breadcrumb
          loadContent($breadcrumb.next(), c);
        }

        /**
         * when a breadcrumb bar item is clicked
         */
        function itemClicked(c, id, type) {
          // check for no href
          //if ($(c).attr('href') === '#') {return false;}
          // check if the click was from the list or an item
          if ($(c).hasClass('ps-bcb-items-list-item')) {
            // set selected item
            $(c).parents('ul').find('.selected').removeClass('selected');
            $(c).parents('li').addClass('selected');
            // find item in the same breadcrumb
            var $item = $(c).parents('div.ps-bcb-breadcrumb').find('a.ps-bcb-item');
            // change its text and href
            $item.attr('href', $(c).attr('href'))
                 .attr('nodeid', $(c).attr('nodeid'))
                 .attr('nodepath', $(c).attr('nodepath'))
                 .attr('nodetype', $(c).attr('nodetype')).text($(c).text());
            // now 'fake click' on it
            loadNextBreadCrumb($item, id, type);
          } else {
            loadNextBreadCrumb(c, id, type);
          }
          if (o.callback) {
            if (typeof(o.callback) === 'function') {
              o.callback(id, $(c).attr('nodepath'), type);
            }
          }
          return false;
        }

        /**
         * bind links in breadcrumb bar
         */
        function bindLinks(c) {
          // show the list (put it in its right place first)
          $(c).find('a.ps-bcb-delim').click(function() {
            $(this).addClass('collapse').removeClass('expand').nextAll('div.ps-bcb-items:first').animate(
                  {left: $(this).position().left, top: $(this).position().top+$(this).height()},10).slideDown(o.speed);
            return false;
          });
          // hide the list
          if ($(c).hasClass('ps-bcb-breadcrumb')) {
            $(c).mouseleave(function() {
              $(this).find('a.ps-bcb-delim').addClass('expand').removeClass('collapse');
              $(this).find('div.ps-bcb-items').slideUp(o.speed);
            });
          } else {
            $(c).find('div.ps-bcb-breadcrumb').mouseleave(function() {
              $(this).find('a.ps-bcb-delim').addClass('expand').removeClass('collapse');
              $(this).find('div.ps-bcb-items').slideUp(o.speed);
            });
          }
          // click on an item in the list
          $(c).find('a.ps-bcb-items-list-item').click(function() {
            itemClicked($(this), $(this).attr('nodeid'), $(this).attr('nodetype'));
            return false;
          });
          // click on an item in the bcb
          $(c).find('a.ps-bcb-item').click(function() {
            itemClicked($(this), $(this).attr('nodeid'), $(this).attr('nodetype'));
            return false;
          });
        }

        // initialise
        bindLinks($(this));

      });
    }
  });
 })(jQuery);
}


