/**
 * Behaviour of the resource view page
 * 
 * @author Christophe Lauret
 * @version 26 October 2010
 */

// Declare all global dependencies for JSLint
/*global PAGESEEDER, $ */

// Defines and invokes an anonymous function to create a closure.
$(document).ready(function() {

  // Base path for CodeMirror
  var cmpath = PublisherContext +'/js/lib/codemirror/';

  // Configuration for the various media types
  function getConfig(type) {
    switch (type) {
      case 'xml': return {
        parserfile: "parsers/parsexml.js",
        stylesheet: cmpath+"css/xmlcolors.css"
      };
      case 'css': return {
        parserfile: "parsers/parsecss.js",
        stylesheet: cmpath+"css/csscolors.css"
      };
      case 'javascript': return {
        parserfile: ["parsers/tokenizejavascript.js","parsers/parsejavascript.js"],
        stylesheet: cmpath+"css/jscolors.css"
      };
      default: return {
        parserfile: "parsers/parsedummy.js",
        stylesheet: cmpath+"css/dummycolors.css"
      };
    }
  }

  $('#source-code').each(function(){
    var $save = $('input.save[type=submit]');
    var type = $('input[name=type]').val();
    var readonly = !!$(this).attr('readonly');
    $('.source').hide();

    // Update the default config
    CodeMirrorConfig.basefiles = ["codemirror-base-0.93.min.js"];
    CodeMirrorConfig.height = "500px";
    CodeMirrorConfig.path = cmpath;

    var defaultConfig = {
      lineNumbers:  true,
      readOnly:     readonly,
      onLoad:       function() { $('.source').delay(300).slideDown();},
      onChange:     function() { $save.removeAttr('disabled').removeClass('disabled');},
      saveFunction: function() { $save.click();}
    };

    var config = $.extend(defaultConfig, getConfig(type));
    
    // Invoke code mirror
    var editor = CodeMirror.fromTextArea('source-code', config);

    // Bind the Save button
    $save.click(function() {
      if ($save.is(':disabled')) { return false; }
      var $form = $(this).closest('form');
      var location = $form.find('input[name=location]').val();
      var content = editor.getCode();
      $save.attr('disabled','disabled').addClass('disabled');
      $('#save-result').text("");
      $.ajax({
        type: "POST",
        url: PublisherContext + '/admin/resources/put.xml',
        data: {'location' : location, 'content' : content, 'overwrite' : 'true'},
        complete: function(xhr, textStatus) {
          if (xhr.status >= 400) {
            alert($(xhr.responseXML).find('message').text());
          } else {
            $save.removeAttr('disabled').removeClass('disabled');
            $('#save-result').fadeTo('fast', 1).text("Last saved "+(new Date()).toLocaleString()).delay(1000).fadeTo("slow", 0.5);
          }
        }
      });
      return false;
    });

  });

});
